=========================================================
``psyclone.tests.psyir.backend.fortran_format_stmt_test``
=========================================================

.. automodule:: psyclone.tests.psyir.backend.fortran_format_stmt_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.fortran_format_stmt_test
